Module: Guard::Jasmine::Formatter
- Defined in:
- lib/guard/jasmine/formatter.rb
Overview
The Guard::Jasmine formatter collects console and system notification methods and enhances them with some color information.
Class Method Summary collapse
-
.debug(message, options = {}) ⇒ Object
Print a debug message to the console.
-
.error(message, options = {}) ⇒ Object
Print a red error message to the console.
-
.info(message, options = {}) ⇒ Object
Print an info message to the console.
-
.notify(message, options = {}) ⇒ Object
Outputs a system notification.
-
.spec_failed(message, options = {}) ⇒ Object
Print a red spec failed message to the console.
-
.spec_pending(message, options = {}) ⇒ Object
Print a yellow pending message to the console.
-
.success(message, options = {}) ⇒ Object
Print a green success message to the console.
-
.suite_name(message, options = {}) ⇒ Object
Print a red spec failed message to the console.
Class Method Details
.debug(message, options = {}) ⇒ Object
Print a debug message to the console.
27 28 29 |
# File 'lib/guard/jasmine/formatter.rb', line 27 def debug(, = {}) Compat::UI.debug(, ) end |
.error(message, options = {}) ⇒ Object
Print a red error message to the console.
37 38 39 |
# File 'lib/guard/jasmine/formatter.rb', line 37 def error(, = {}) Compat::UI.error(color(, ';31'), ) end |
.info(message, options = {}) ⇒ Object
Print an info message to the console.
17 18 19 |
# File 'lib/guard/jasmine/formatter.rb', line 17 def info(, = {}) Compat::UI.info(, ) end |
.notify(message, options = {}) ⇒ Object
Outputs a system notification.
86 87 88 |
# File 'lib/guard/jasmine/formatter.rb', line 86 def notify(, = {}) Compat::UI.notify(, ) end |
.spec_failed(message, options = {}) ⇒ Object
Print a red spec failed message to the console.
66 67 68 |
# File 'lib/guard/jasmine/formatter.rb', line 66 def spec_failed(, = {}) Compat::UI.info(color(, ';31'), ) end |
.spec_pending(message, options = {}) ⇒ Object
Print a yellow pending message to the console.
57 58 59 |
# File 'lib/guard/jasmine/formatter.rb', line 57 def spec_pending(, = {}) Compat::UI.info(color(, ';33'), ) end |
.success(message, options = {}) ⇒ Object
Print a green success message to the console.
47 48 49 |
# File 'lib/guard/jasmine/formatter.rb', line 47 def success(, = {}) Compat::UI.info(color(, ';32'), ) end |
.suite_name(message, options = {}) ⇒ Object
Print a red spec failed message to the console.
75 76 77 |
# File 'lib/guard/jasmine/formatter.rb', line 75 def suite_name(, = {}) Compat::UI.info(color(, ';33'), ) end |