Module: Guard::Jasmine::Inspector
- Defined in:
- lib/guard/jasmine/inspector.rb
Overview
The inspector verifies if the changed paths are valid for Guard::Jasmine. Please note that request to Inspector.clean paths keeps the current valid files cached until clear is called.
Class Method Summary collapse
-
.clean(paths, options) ⇒ Array<String>
Clean the changed paths and return only valid Jasmine specs in either JavaScript or CoffeeScript.
Class Method Details
.clean(paths, options) ⇒ Array<String>
Clean the changed paths and return only valid Jasmine specs in either JavaScript or CoffeeScript.
20 21 22 23 24 25 26 27 28 29 30 |
# File 'lib/guard/jasmine/inspector.rb', line 20 def clean(paths, ) paths.uniq! paths.compact! paths = if paths.include?([:spec_dir]) [[:spec_dir]] else paths.select { |p| jasmine_spec?(p) } end paths end |